"""Module with UUIDs and names for Bluetooth services.

Usage:

>>> from bluetooth_numbers import service
>>> from uuid import UUID
>>> service[0x180F]
'Battery Service'
>>> service[UUID("6E400001-B5A3-F393-E0A9-E50E24DCCA9E")]
'Nordic UART Service'
"""
from uuid import UUID

from bluetooth_numbers.dicts import UUIDDict

service = UUIDDict(
    {
        0x1800: "Generic Access",
        0x1811: "Alert Notification Service",
        0x1815: "Automation IO",
        0x180F: "Battery Service",
        0x1810: "Blood Pressure",
        0x181B: "Body Composition",
        0x181E: "Bond Management Service",
        0x181F: "Continuous Glucose Monitoring",
        0x1805: "Current Time Service",
        0x1818: "Cycling Power",
        0x1816: "Cycling Speed and Cadence",
        0x180A: "Device Information",
        0x181A: "Environmental Sensing",
        0x1826: "Fitness Machine",
        0x1801: "Generic Attribute",
        0x1808: "Glucose",
        0x1809: "Health Thermometer",
        0x180D: "Heart Rate",
        0x1823: "HTTP Proxy",
        0x1812: "Human Interface Device",
        0x1802: "Immediate Alert",
        0x1821: "Indoor Positioning",
        0x183A: "Insulin Delivery",
        0x1820: "Internet Protocol Support Service",
        0x1803: "Link Loss",
        0x1819: "Location and Navigation",
        0x1827: "Mesh Provisioning Service",
        0x1828: "Mesh Proxy Service",
        0x1807: "Next DST Change Service",
        0x1825: "Object Transfer Service",
        0x180E: "Phone Alert Status Service",
        0x1822: "Pulse Oximeter Service",
        0x1829: "Reconnection Configuration",
        0x1806: "Reference Time Update Service",
        0x1814: "Running Speed and Cadence",
        0x1813: "Scan Parameters",
        0x1824: "Transport Discovery",
        0x1804: "Tx Power",
        0x181C: "User Data",
        0x181D: "Weight Scale",
        0x183B: "Binary Sensor",
        0x183C: "Emergency Configuration",
        0x183E: "Physical Activity Monitor",
        0x1843: "Audio Input Control",
        0x1844: "Volume Control",
        0x1845: "Volume Offset Control",
        0x1846: "Coordinated Set Identification",
        0x1847: "Device Time",
        0x1848: "Media Control",
        0x1849: "Generic Media Control",
        0x184A: "Constant Tone Extension",
        0x184B: "Telephone Bearer",
        0x184C: "Generic Telephone Bearer",
        0x184D: "Microphone Control",
        0x184E: "Audio Stream Control",
        0x184F: "Broadcast Audio Scan",
        0x1850: "Published Audio Capabilities",
        0x1851: "Basic Audio Announcement",
        0x1852: "Broadcast Audio Announcement",
        0x1853: "Common Audio",
        0x1854: "Hearing Access",
        0x1855: "TMAS",
        0xFE0F: "Signify Netherlands B.V. (formerly Philips Lighting) Service",
        0xFEAA: "Eddystone",
        0xFE2C: "Fast Pair Service",
        0xFE59: "Secure DFU Service",
        0xFD6F: "Exposure Notification Service",
        0xFEBB: "File Transfer Service by Adafruit",
        0xFD0D: "Blecon Advertising Service",
        0x65279: "GN Netcom",
        0x65278: "GN Hearing A/S",
        0x65277: "Gimbal, Inc.",
        0x65276: "Gimbal, Inc.",
        0x65275: "Telit Wireless Solutions (Formerly Stollmann E+V GmbH)",
        0x65274: "PayPal, Inc.",
        0x65273: "PayPal, Inc.",
        0x65272: "Aplix Corporation",
        0x65271: "Aplix Corporation",
        0x65270: "Wicentric, Inc.",
        0x65269: "Dialog Semiconductor GmbH",
        0x65268: "Google LLC",
        0x65267: "Google LLC",
        0x65266: "CSR",
        0x65265: "CSR",
        0x65264: "Intel",
        0x65263: "Polar Electro Oy",
        0x65262: "Polar Electro Oy",
        0x65261: "Tile, Inc.",
        0x65260: "Tile, Inc.",
        0x65259: "Swirl Networks, Inc.",
        0x65258: "Swirl Networks, Inc.",
        0x65257: "Quintic Corp.",
        0x65256: "Quintic Corp.",
        0x65255: "Tencent Holdings Limited.",
        0x65254: "Silvair, Inc.",
        0x65253: "Nordic Semiconductor ASA",
        0x65252: "Nordic Semiconductor ASA",
        0x65251: "Anki, Inc.",
        0x65250: "Anki, Inc.",
        0x65249: "Anhui Huami Information Technology Co., Ltd.",
        0x65248: "Anhui Huami Information Technology Co., Ltd.",
        0x65247: "Design SHIFT",
        0x65246: "Coin, Inc.",
        0x65245: "Jawbone",
        0x65244: "Jawbone",
        0x65243: "Perka, Inc.",
        0x65242: "ISSC Technologies Corp.",
        0x65241: "Pebble Technology Corporation",
        0x65240: "Google LLC",
        0x65239: "Broadcom",
        0x65238: "Broadcom",
        0x65237: "Plantronics Inc.",
        0x65236: "Apple, Inc.",
        0x65235: "Apple, Inc.",
        0x65234: "Apple, Inc.",
        0x65233: "Apple, Inc.",
        0x65232: "Apple, Inc.",
        0x65231: "Apple, Inc.",
        0x65230: "Apple, Inc.",
        0x65229: "Apple, Inc.",
        0x65228: "Apple, Inc.",
        0x65227: "Apple, Inc.",
        0x65226: "Apple, Inc.",
        0x65225: "Apple, Inc.",
        0x65224: "Apple, Inc.",
        0x65223: "Apple, Inc.",
        0x65222: "Kocomojo, LLC",
        0x65221: "Realtek Semiconductor Corp.",
        0x65220: "PLUS Location Systems",
        0x65219: "360fly, Inc.",
        0x65218: "Blue Spark Technologies, Inc.",
        0x65217: "KDDI Corporation",
        0x65216: "KDDI Corporation",
        0x65215: "Nod, Inc.",
        0x65214: "Bose Corporation",
        0x65213: "Clover Network, Inc",
        0x65212: "Dexcom Inc",
        0x65211: "adafruit industries",
        0x65210: "Tencent Holdings Limited",
        0x65209: "LG Electronics",
        0x65208: "Meta Platforms, Inc.",
        0x65207: "Meta Platforms, Inc.",
        0x65206: "Vencer Co., Ltd",
        0x65205: "WiSilica Inc.",
        0x65204: "WiSilica Inc.",
        0x65203: "Taobao",
        0x65202: "Microsoft Corporation",
        0x65201: "Electronics Tomorrow Limited",
        0x65200: "Nest Labs Inc",
        0x65199: "Nest Labs Inc",
        0x65198: "Nokia",
        0x65197: "Nokia",
        0x65196: "Nokia",
        0x65195: "Nokia",
        0x65194: "Google LLC",
        0x65193: "Savant Systems LLC",
        0x65192: "Savant Systems LLC",
        0x65191: "UTC Fire and Security",
        0x65190: "GoPro, Inc.",
        0x65189: "GoPro, Inc.",
        0x65188: "Paxton Access Ltd",
        0x65187: "ITT Industries",
        0x65186: "Intrepid Control Systems, Inc.",
        0x65185: "Intrepid Control Systems, Inc.",
        0x65184: "Google LLC",
        0x65183: "Google LLC",
        0x65182: "Dialog Semiconductor B.V.",
        0x65181: "Mobiquity Networks Inc",
        0x65180: "GSI Laboratories, Inc.",
        0x65179: "Samsara Networks, Inc",
        0x65178: "Estimote",
        0x65177: "Currant Inc",
        0x65176: "Currant Inc",
        0x65175: "Tesla Motors Inc.",
        0x65174: "Tesla Motors Inc.",
        0x65173: "Xiaomi Inc.",
        0x65172: "OttoQ In",
        0x65171: "OttoQ In",
        0x65170: "Jarden Safety & Security",
        0x65169: "Shanghai Imilab Technology Co.,Ltd",
        0x65168: "JUMA",
        0x65167: "CSR",
        0x65166: "ARM Ltd",
        0x65165: "Interaxon Inc.",
        0x65164: "TRON Forum",
        0x65163: "Apple, Inc.",
        0x65162: "Apple, Inc.",
        0x65161: "B&O Play A/S",
        0x65160: "SALTO SYSTEMS S.L.",
        0x65159: "Qingdao Yeelink Information Technology Co., Ltd. ( 青岛亿联客信息技术有限公司 )",
        0x65158: "HUAWEI Technologies Co., Ltd",
        0x65157: "RF Digital Corp",
        0x65156: "RF Digital Corp",
        0x65155: "Blue Bite",
        0x65154: "Medtronic Inc.",
        0x65153: "Medtronic Inc.",
        0x65152: "Doppler Lab",
        0x65151: "Doppler Lab",
        0x65150: "Awear Solutions Ltd",
        0x65149: "Aterica Health Inc.",
        0x65148: "Telit Wireless Solutions (Formerly Stollmann E+V GmbH)",
        0x65147: "Orion Labs, Inc.",
        0x65146: "Bragi GmbH",
        0x65145: "Zebra Technologies",
        0x65144: "Hewlett-Packard Company",
        0x65143: "Hewlett-Packard Company",
        0x65142: "TangoMe",
        0x65141: "TangoMe",
        0x65140: "unwire",
        0x65139: "Abbott (formerly St. Jude Medical, Inc.)",
        0x65138: "Abbott (formerly St. Jude Medical, Inc.)",
        0x65137: "Plume Design Inc",
        0x65136: "Beijing Jingdong Century Trading Co., Ltd.",
        0x65135: "LINE Corporation",
        0x65134: "The University of Tokyo",
        0x65133: "The University of Tokyo",
        0x65132: "TASER International, Inc.",
        0x65131: "TASER International, Inc.",
        0x65130: "Kontakt Micro-Location Sp. z o.o.",
        0x65129: "Capsle Technologies Inc.",
        0x65128: "Capsle Technologies Inc.",
        0x65127: "Lab Sensor Solutions",
        0x65126: "Intel Corporation",
        0x65125: "CHIPOLO d.o.o.",
        0x65124: "Siemens AG",
        0x65123: "Connected Yard, Inc.",
        0x65122: "Indagem Tech LLC",
        0x65121: "Logitech International SA",
        0x65120: "Lierda Science & Technology Group Co., Ltd.",
        0x65119: "Eyefi, Inc.",
        0x65118: "Plastc Corporation",
        0x65117: "Grundfos A/S",
        0x65116: "million hunters GmbH",
        0x65115: "GT-tronics HK Ltd",
        0x65114: "Cronologics Corporation",
        0x65113: "Nordic Semiconductor ASA",
        0x65112: "Nordic Semiconductor ASA",
        0x65111: "Dotted Labs",
        0x65110: "Google LLC",
        0x65109: "Google LLC",
        0x65108: "Motiv, Inc.",
        0x65107: "3M",
        0x65106: "SetPoint Medical",
        0x65105: "SRAM",
        0x65104: "Google LLC",
        0x65103: "Molekule, Inc.",
        0x65102: "NTT docomo",
        0x65101: "Casambi Technologies Oy",
        0x65100: "Volkswagen AG",
        0x65099: "Signify Netherlands B.V. (formerly Philips Lighting B.V.)",
        0x65098: "OMRON HEALTHCARE Co., Ltd.",
        0x65097: "SenionLab AB",
        0x65096: "General Motors",
        0x65095: "General Motors",
        0x65094: "B&O Play A/S",
        0x65093: "Snapchat Inc",
        0x65092: "SK Telecom",
        0x65091: "Andreas Stihl AG & Co. KG",
        0x65090: "Nets A/S",
        0x65089: "Inugo Systems Limited",
        0x65088: "Inugo Systems Limited",
        0x65087: "Friday Labs Limited",
        0x65086: "BD Medical",
        0x65085: "BD Medical",
        0x65084: "alibaba",
        0x65083: "Dolby Laboratories",
        0x65082: "TTS Tooltechnic Systems AG & Co. KG",
        0x65081: "TTS Tooltechnic Systems AG & Co. KG",
        0x65080: "Spaceek LTD",
        0x65079: "Spaceek LTD",
        0x65078: "HUAWEI Technologies Co., Ltd",
        0x65077: "HUAWEI Technologies Co., Ltd",
        0x65076: "SmallLoop LLC",
        0x65075: "CHIPOLO d.o.o.",
        0x65074: "Pro-Mark, Inc.",
        0x65073: "Volkswagen AG",
        0x65072: "Volkswagen AG",
        0x65071: "CRESCO Wireless, Inc",
        0x65070: "ERi,Inc.",
        0x65069: "LAMPLIGHT Co., Ltd.",
        0x65068: "Google LLC",
        0x65067: "ITT Industries",
        0x65066: "DaisyWorks, Inc.",
        0x65065: "Gibson Innovations",
        0x65064: "Ayla Networks",
        0x65063: "Google LLC",
        0x65062: "Google LLC",
        0x65061: "Apple, Inc.",
        0x65060: "August Home Inc",
        0x65059: "Zoll Medical Corporation",
        0x65058: "Zoll Medical Corporation",
        0x65057: "Bose Corporation",
        0x65056: "Emerson",
        0x65055: "Garmin International, Inc.",
        0x65054: "LAMPLIGHT Co., Ltd.",
        0x65053: "Illuminati Instrument Corporation",
        0x65052: "NetMedia, Inc.",
        0x65051: "Tyto Life LLC",
        0x65050: "Tyto Life LLC",
        0x65049: "Google LLC",
        0x65048: "Runtime, Inc.",
        0x65047: "Telit Wireless Solutions GmbH",
        0x65046: "Footmarks, Inc.",
        0x65045: "Amazon.com Services, Inc..",
        0x65044: "Flextronics International USA Inc.",
        0x65043: "Apple Inc.",
        0x65042: "M-Way Solutions GmbH",
        0x65041: "GMC-I Messtechnik GmbH",
        0x65040: "LAPIS Technology Co., Ltd.",
        0x65039: "Signify Netherlands B.V. (formerly Philips Lighting B.V.)",
        0x65038: "Setec Pty Ltd",
        0x65037: "Procter & Gamble",
        0x65036: "Procter & Gamble",
        0x65035: "ruwido austria gmbh",
        0x65034: "ruwido austria gmbh",
        0x65033: "Pillsy, Inc.",
        0x65032: "Microsoft",
        0x65031: "Sonos, Inc.",
        0x65030: "Qualcomm Technologies, Inc.",
        0x65029: "CORE Transport Technologies NZ Limited",
        0x65028: "Motorola Solutions, Inc.",
        0x65027: "Amazon.com Services, Inc.",
        0x65026: "Robert Bosch GmbH",
        0x65025: "Duracell U.S. Operations Inc.",
        0x65024: "Amazon.com Services, Inc.",
        0x65023: "OSRAM GmbH",
        0x65022: "ADHERIUM(NZ) LIMITED",
        0x65021: "RecursiveSoft Inc.",
        0x65020: "Optrel AG",
        0x65019: "Tandem Diabetes Care",
        0x65018: "Tandem Diabetes Care",
        0x65017: "INIA",
        0x65016: "Onvocal",
        0x65015: "HP Inc.",
        0x65014: "AIAIAI ApS",
        0x65013: "Milwaukee Electric Tools",
        0x65012: "O. E. M. Controls, Inc.",
        0x65011: "Amersports",
        0x65010: "AMICCOM Electronics Corporation",
        0x65009: "LAMPLIGHT Co.,Ltd",
        0x65008: "Google LLC",
        0x65007: "ART AND PROGRAM, INC.",
        0x65006: "Huawei Technologies Co., Ltd.",
        0x65005: "Pole Star",
        0x65004: "Mannkind Corporation",
        0x65003: "Syntronix Corporation",
        0x65002: "SeeScan, Inc",
        0x65001: "Spacesaver Corporation",
        0x65000: "Robert Bosch GmbH",
        0x64999: "SECOM Co., LTD",
        0x64998: "Intelletto Technologies Inc",
        0x64997: "SMK Corporation",
        0x64996: "JUUL Labs, Inc.",
        0x64995: "Abbott Diabetes Care",
        0x64994: "Google LLC",
        0x64993: "Fortin Electronic Systems",
        0x64992: "John Deere",
        0x64991: "Harman International",
        0x64990: "Noodle Technology Inc.",
        0x64989: "Arch Systems Inc",
        0x64988: "4iiii Innovations Inc.",
        0x64987: "Samsung Electronics Co., Ltd.",
        0x64986: "MHCS",
        0x64985: "Jiangsu Teranovo Tech Co., Ltd.",
        0x64984: "Jiangsu Teranovo Tech Co., Ltd.",
        0x64983: "Emerson",
        0x64982: "Ministry of Supply",
        0x64981: "Brompton Bicycle Ltd",
        0x64980: "LX Solutions Pty Limited",
        0x64979: "FUBA Automotive Electronics GmbH",
        0x64978: "Bose Corporation",
        0x64977: "Huawei Technologies Co., Ltd",
        0x64976: "Huawei Technologies Co., Ltd",
        0x64975: "Nalu Medical, Inc",
        0x64974: "SENNHEISER electronic GmbH & Co. KG",
        0x64973: "Qingping Technology (Beijing) Co., Ltd.",
        0x64972: "Shoof Technologies",
        0x64971: "Meggitt SA",
        0x64970: "Fortin Electronic Systems",
        0x64969: "Busch-Jaeger Elektro GmbH",
        0x64968: "Hach - Danaher",
        0x64967: "Eli Lilly and Company",
        0x64966: "Eli Lilly and Company",
        0x64965: "Automatic Labs",
        0x64964: "Simavita (Aust) Pty Ltd",
        0x64963: "Baidu Online Network Technology (Beijing) Co., Ltd",
        0x64962: "Baidu Online Network Technology (Beijing) Co., Ltd",
        0x64961: "Hunter Douglas",
        0x64960: "Hunter Douglas",
        0x64959: "California Things Inc.",
        0x64958: "California Things Inc.",
        0x64957: "Clover Network, Inc.",
        0x64956: "Emerson",
        0x64955: "Profoto",
        0x64954: "Comcast Cable Corporation",
        0x64953: "Comcast Cable Corporation",
        0x64952: "LivaNova USA Inc.",
        0x64951: "LivaNova USA Inc.",
        0x64950: "GWA Hygiene GmbH",
        0x64949: "ECSG",
        0x64948: "HP Inc",
        0x64947: "Audiodo AB",
        0x64946: "Portable Multimedia Ltd",
        0x64945: "Oura Health Ltd",
        0x64944: "Oura Health Ltd",
        0x64943: "Wiliot LTD",
        0x64942: "Houwa System Design, k.k.",
        0x64941: "Houwa System Design, k.k.",
        0x64940: "Tentacle Sync GmbH",
        0x64939: "Xiaomi Inc.",
        0x64938: "Xiaomi Inc.",
        0x64937: "Rhombus Systems, Inc.",
        0x64936: "PSA Peugeot Citroën",
        0x64935: "WWZN Information Technology Company Limited",
        0x64934: "WWZN Information Technology Company Limited",
        0x64933: "Neurostim OAB, Inc.",
        0x64932: "Inseego Corp.",
        0x64931: "Inseego Corp.",
        0x64930: "Groove X, Inc",
        0x64929: "Groove X, Inc",
        0x64928: "Secugen Corporation",
        0x64927: "VitalTech Affiliates LLC",
        0x64926: "The Coca-Cola Company",
        0x64925: "Gastec Corporation",
        0x64924: "Huawei Technologies Co., Ltd.",
        0x64923: "Huawei Technologies Co., Ltd.",
        0x64922: "Huawei Technologies Co., Ltd.",
        0x64921: "ABB Oy",
        0x64920: "Disney Worldwide Services, Inc.",
        0x64919: "June Life, Inc.",
        0x64918: "Google LLC",
        0x64917: "Rigado",
        0x64916: "Hewlett Packard Enterprise",
        0x64915: "Bayerische Motoren Werke AG",
        0x64914: "Qualcomm Technologies International, Ltd. (QTIL)",
        0x64913: "Groove X, Inc.",
        0x64912: "Guangzhou SuperSound Information Technology Co.,Ltd",
        0x64911: "Matrix ComSec Pvt. Ltd.",
        0x64910: "Motorola Solutions",
        0x64909: "quip NYC Inc.",
        0x64908: "Google LLC",
        0x64907: "Jigowatts Inc.",
        0x64906: "Signify Netherlands B.V.",
        0x64905: "Urbanminded LTD",
        0x64904: "Urbanminded LTD",
        0x64903: "Google LLC",
        0x64902: "Abbott",
        0x64901: "Husqvarna AB",
        0x64900: "Tile, Inc.",
        0x64899: "iNFORM Technology GmbH",
        0x64898: "Sony Corporation",
        0x64897: "CANDY HOUSE, Inc.",
        0x64896: "Phindex Technologies, Inc",
        0x64895: "Husqvarna AB",
        0x64894: "Samsung Electronics Co., Ltd.",
        0x64893: "Center for Advanced Research Wernher Von Braun",
        0x64892: "Toshiba Information Systems(Japan) Corporation",
        0x64891: "WYZE LABS, INC.",
        0x64890: "Withings",
        0x64889: "Withings",
        0x64888: "Withings",
        0x64887: "Withings",
        0x64886: "Insulet Corporation",
        0x64885: "Insulet Corporation",
        0x64884: "BRControls Products BV",
        0x64883: "BRControls Products BV",
        0x64882: "Logitech International SA",
        0x64881: "GN Hearing A/S",
        0x64880: "GuangDong Oppo Mobile Telecommunications Corp., Ltd",
        0x64879: "Apple, Inc.",
        0x64878: "Polidea sp. z o.o.",
        0x64877: "Sigma Elektro GmbH",
        0x64876: "Samsung Electronics Co., Ltd.",
        0x64875: "rapitag GmbH",
        0x64874: "Emerson",
        0x64873: "Samsung Electronics Co., Ltd",
        0x64872: "Ubique Innovation AG",
        0x64871: "Montblanc Simplo GmbH",
        0x64870: "Zebra Technologies Corporation",
        0x64869: "Razer Inc.",
        0x64868: "INRIA",
        0x64867: "Google LLC",
        0x64866: "Google LLC",
        0x64865: "Arendi AG",
        0x64864: "Sercomm Corporation",
        0x64863: "Meta Platforms Technologies, LLC",
        0x64862: "Tapkey GmbH",
        0x64861: "maxon motor ltd.",
        0x64860: "React Mobile",
        0x64859: "V2SOFT INC.",
        0x64858: "Samsung Electronics Co., Ltd.",
        0x64857: "Samsung Electronics Co., Ltd.",
        0x64856: "Volvo Car Corporation",
        0x64855: "Volvo Car Corporation",
        0x64854: "Resmed Ltd",
        0x64853: "Braveheart Wireless, Inc.",
        0x64852: "Qingdao Haier Technology Co., Ltd.",
        0x64851: "PCI Private Limited",
        0x64850: "UTC Fire and Security",
        0x64849: "UTC Fire and Security",
        0x64848: "Hangzhou Tuya Information  Technology Co., Ltd",
        0x64847: "SONITOR TECHNOLOGIES AS",
        0x64846: "70mai Co.,Ltd.",
        0x64845: "70mai Co.,Ltd.",
        0x64844: "Adolf Wuerth GmbH & Co KG",
        0x64843: "Samsung Electronics Co., Ltd.",
        0x64842: "Sigma Elektro GmbH",
        0x64841: "Panasonic Corporation",
        0x64840: "Geberit International AG",
        0x64839: "Liberty Global Inc.",
        0x64838: "Lemco IKE",
        0x64837: "GB Solution co.,Ltd",
        0x64836: "Apple Inc.",
        0x64835: "Apple Inc.",
        0x64834: "Globe (Jiangsu) Co.,Ltd",
        0x64833: "Amazon Lab126",
        0x64832: "Beflex Inc.",
        0x64831: "Cognosos, Inc",
        0x64830: "Pure Watercraft, inc.",
        0x64829: "Woan Technology (Shenzhen) Co., Ltd.",
        0x64828: "Redline Communications Inc.",
        0x64827: "Verkada Inc.",
        0x64826: "Verkada Inc.",
        0x64825: "PREDIKTAS",
        0x64824: "Danfoss A/S",
        0x64823: "TireCheck GmbH",
        0x64822: "Google LLC",
        0x64821: "Transsion Holdings Limited",
        0x64820: "Aerosens LLC.",
        0x64819: "DashLogic, Inc.",
        0x64818: "Gemalto Holding BV",
        0x64817: "LG Electronics Inc.",
        0x64816: "Sesam Solutions BV",
        0x64815: "Bitstrata Systems Inc.",
        0x64814: "Bitstrata Systems Inc.",
        0x64813: "Xiaomi Inc.",
        0x64812: "The Access Technologies",
        0x64811: "The Access Technologies",
        0x64810: "Sony Corporation",
        0x64809: "Asahi Kasei Corporation",
        0x64808: "Julius Blum GmbH",
        0x64807: "Integrated Illumination Systems, Inc.",
        0x64806: "Novo Nordisk A/S",
        0x64805: "GD Midea Air-Conditioning Equipment Co., Ltd.",
        0x64804: "GD Midea Air-Conditioning Equipment Co., Ltd.",
        0x64803: "DOM Sicherheitstechnik GmbH & Co. KG",
        0x64802: "Huawei Technologies Co., Ltd.",
        0x64801: "Huawei Technologies Co., Ltd.",
        0x64800: "GN Hearing A/S",
        0x64799: "3M",
        0x64798: "Plume Design Inc.",
        0x64797: "Samsung Electronics Co., Ltd",
        0x64796: "Brady Worldwide Inc.",
        0x64795: "Helios Sports, Inc.",
        0x64794: "CSIRO",
        0x64793: "Smith & Nephew Medical Limited",
        0x64792: "LEGIC Identsystems AG",
        0x64791: "LEGIC Identsystems AG",
        0x64790: "Sensitech, Inc.",
        0x64789: "Panasonic Corporation",
        0x64788: "BRG Sports, Inc.",
        0x64787: "BRG Sports, Inc.",
        0x64786: "AEON MOTOR CO.,LTD.",
        0x64785: "AEON MOTOR CO.,LTD.",
        0x64784: "AEON MOTOR CO.,LTD.",
        0x64783: "AEON MOTOR CO.,LTD.",
        0x64782: "HerdDogg, Inc",
        0x64781: "Blecon Ltd",
        0x64780: "OSM HK Limited",
        0x64779: "Luminostics, Inc.",
        0x64778: "Luminostics, Inc.",
        0x64777: "Cousins and Sears LLC",
        0x64776: "Bull Group Incorporated Company",
        0x64775: "Swedlock AB",
        0x64774: "RACE-AI LLC",
        0x64773: "Qualcomm Technologies, Inc.",
        0x64772: "Shure Inc.",
        0x64771: "Quuppa Oy",
        0x64770: "LEGO System A/S",
        0x64769: "Sanvita Medical Corporation",
        0x64768: "FUTEK Advanced Sensor Technology, Inc.",
        0x64767: "701x",
        0x64766: "Sonova Consumer Hearing GmbH",
        0x64765: "Barrot Technology Co.,Ltd.",
        0x64764: "Barrot Technology Co.,Ltd.",
        0x64763: "Shenzhen Benwei Media Co., Ltd.",
        0x64762: "Leupold & Stevens, Inc.",
        0x64761: "Leupold & Stevens, Inc.",
        0x64760: "Honor Device Co., Ltd.",
        0x64759: "Honor Device Co., Ltd.",
        0x64758: "The Linux Foundation",
        0x64757: "Trident Communication Technology, LLC",
        0x64756: "Allegion",
        0x64755: "Armatura LLC",
        0x64754: "Bitwards Oy",
        0x64753: "Google LLC",
        0x64752: "Security Enhancement Systems, LLC",
        0x64751: "Divesoft s.r.o.",
        0x64750: "Velentium, LLC",
        0x64749: "Workaround Gmbh",
        0x64748: "Griffwerk GmbH",
        0x64747: "Avi-On",
        0x64746: "Chess Wise B.V.",
        0x64745: "MindRhythm, Inc.",
        0x64744: "ITT Industries",
        0x64743: "TKH Security B.V.",
        0x64742: "Guard RFID Solutions Inc.",
        0x64741: "Samsara Networks, Inc",
        0x64740: "Samsara Networks, Inc",
        0x64739: "Smith & Nephew Medical Limited",
        0x64738: "Baracoda Daily Healthtech",
        0x64737: "Sony Group Corporation",
        0x64736: 'Akciju sabiedriba "SAF TEHNIKA"',
        0x64735: "NIO USA, Inc.",
        0x64734: "ARCTOP, INC.",
        0x64733: "Mobilaris AB",
        0x64732: "Amazon.com Services, LLC",
        0x64731: "aconno GmbH",
        0x64730: "Draeger",
        0x64729: "Huso, INC",
        0x64728: "Appex Factory S.L.",
        0x64727: "PowerPal Pty Ltd",
        0x64726: "SWISSINNO SOLUTIONS AG",
        0x64725: "Nortek Security & Control",
        0x64724: "OMRON HEALTHCARE",
        0x64723: "Fisher & Paykel Healthcare",
        0x64722: "Allterco Robotics ltd",
        0x64721: "Shenzhen Benwei Media Co.,Ltd.",
        0x64720: "Laerdal Medical AS",
        0x64719: "Google LLC",
        0x64718: "Luna Health, Inc.",
        0x64717: "Zound Industries International AB",
        0x64715: "TOTO LTD.",
        0x64714: "Cosmed s.r.l.",
        0x64713: "SkyHawke Technologies",
        0x64712: "Allthenticate, Inc.",
        0x64711: "PB INC.",
        0x64710: "Wiliot LTD.",
        0x64709: "OMRON(DALIAN) CO,.LTD.",
        0x64708: "OMRON(DALIAN) CO,.LTD.",
        0x64707: "HP Inc.",
        0x64706: "Qualcomm Technologies, Inc.",
        0x64705: "TIMECODE SYSTEMS LIMITED",
        0x64704: "Xiaomi Inc.",
        0x64703: "ASSA ABLOY Opening Solutions Sweden AB",
        0x64702: "Musen Connect, Inc.",
        0x64701: "Toshiba Corporation",
        0x64700: "Drowsy Digital, Inc.",
        0x64699: "SharkNinja Operating LLC",
        0x64698: "BlueID GmbH",
        0x64697: "Lumi United Technology Co., Ltd",
        0x64696: "Ribbiot, INC.",
        0x64695: "T-Mobile USA",
        0x64694: "OMRON HEALTHCARE Co., Ltd.",
        0x64693: "OMRON HEALTHCARE Co., Ltd.",
        0x64692: "OMRON HEALTHCARE Co., Ltd.",
        0x64691: "SWEEN",
        0x64690: "Apple Inc.",
        0x64689: "Google LLC",
        0x64688: "Ford Motor Company",
        0x64687: "AltoBeam Inc.",
        0x64686: "Imagine Marketing Limited",
        0x64685: "Beijing 99help Safety Technology Co., Ltd",
        0x64684: "IRISS INC.",
        0x64683: "IRISS INC.",
        0x64682: "Spintly, Inc.",
        0x64681: "Medtronic Inc.",
        0x64680: "Medtronic Inc.",
        0x64679: "Hubble Network Inc.",
        0x64678: "Hubble Network Inc.",
        0x64677: "HAYWARD INDUSTRIES, INC.",
        0x64676: "HP Inc.",
        0x64675: "Gunnebo Aktiebolag",
        0x64674: "Meizu Technology Co., Ltd.",
        0x64673: "PF SCHWEISSTECHNOLOGIE GMBH",
        0x64672: "Apple Inc.",
        0x64671: "Delta Development Team, Inc",
        0x64670: "Dell Computer Corporation",
        0x64669: "Lenovo (Singapore) Pte Ltd.",
        0x64668: "Binary Power, Inc.",
        0x64667: "Merry Electronics (S) Pte Ltd",
        0x64666: "Plockat Solutions AB",
        0x64665: "Badger Meter",
        0x64664: "Ruuvi Innovations Ltd.",
        0x64663: "Japan Display Inc.",
        0x64662: "LEGO System A/S",
        0x64661: "Hippo Camp Software Ltd.",
        0x64660: "Apple Inc.",
        0x64659: "Komatsu Ltd.",
        0x64658: "Furuno Electric Co., Ltd.",
        0x64657: "Samsung Electronics Co., Ltd.",
        0x64656: "Wiliot LTD.",
        0x64655: "Bose Corporation",
        0x64654: "Blue Iris Labs, Inc.",
        0x64653: "Caire Inc.",
        0x64652: "SES-Imagotag",
        0x64651: "Kaspersky Lab Middle East FZ-LLC",
        0x64650: "Intel Corporation",
        0x64649: "Intel Corporation",
        0x64648: "CCC del Uruguay",
        0x64647: "Samsara Networks, Inc",
        0x64646: "Samsara Networks, Inc",
        0x64645: "Zhejiang Huanfu Technology Co., LTD",
        0x64644: "NINGBO FOTILE KITCHENWARE CO., LTD.",
        0x64643: "iHealth Labs, Inc.",
        0x64642: "Zwift, Inc.",
        0x64641: "Axon Enterprise, Inc.",
        0x64640: "TELE System Communications Pte. Ltd.",
        0x64639: "Southco",
        0x64638: "Harman International",
        0x64637: "MML US, Inc",
        0x64636: "Motorola Mobility, LLC",
        0x64635: "Testo SE & Co. KGaA",
        0x64634: "Outshiny India Private Limited",
        0x64633: "LG Electronics Inc.",
        0x64632: "DHL",
        0x64631: "SING SUN TECHNOLOGY (INTERNATIONAL) LIMITED",
        0x64630: "Weber-Stephen Products LLC",
        0x64629: "Xiaomi Inc.",
        0x65534: "Wireless Power Transfer",
        0x65533: "Universal Second Factor Authenticator",
        0x65532: "Wireless Power Transfer (WPT)",
        0x65531: "Direct Thread Commissioning",
        0x65530: "ASTM Remote ID",
        0x65529: "FIDO2 secure client-to-authenticator transport",
        0x65528: "Mopria Alliance BLE",
        0x65527: "Zigbee Direct",
        0x65526: "Matter Profile ID",
        0x65525: "Car Connectivity Consortium, LLC",
        0x65524: "FiRa Consortium",
        0x65523: "FiRa Consortium",
        0x65522: "Aliro",
        0x65521: "ICCE Digital Key",
        0x65520: "Public Key Open Credential (PKOC)",
        0x65519: "Wi-Fi Direct Specification",
        0x64716: "Wi-Fi Easy Connect Specification",
        UUID(
            "932C32BD-0000-47A2-835A-A8D455B859DD",
        ): "Philips Hue Light Control Service",
        UUID(
            "B8843ADD-0000-4AA1-8794-C3F462030BDA",
        ): "Philips Hue Light Update Service",
        UUID(
            "7905F431-B5CE-4E99-A40F-4B1E122D00D0",
        ): "Apple Notification Center Service",
        UUID("89D3502B-0F36-433A-8EF4-C502AD55F8DC"): "Apple Media Service",
        UUID("7DFC6000-7D1C-4951-86AA-8D9728F8D66C"): "Apple Reserved Service",
        UUID("7DFC7000-7D1C-4951-86AA-8D9728F8D66C"): "Apple Reserved Service",
        UUID("7DFC8000-7D1C-4951-86AA-8D9728F8D66C"): "Apple Reserved Service",
        UUID("7DFC9000-7D1C-4951-86AA-8D9728F8D66C"): "Apple Reserved Service",
        UUID("E95D0753-251D-470A-A062-FA1922DFA9A8"): "micro:bit Accelerometer Service",
        UUID("E95DF2D8-251D-470A-A062-FA1922DFA9A8"): "micro:bit Magnetometer Service",
        UUID("E95D9882-251D-470A-A062-FA1922DFA9A8"): "micro:bit Button Service",
        UUID("E95D127B-251D-470A-A062-FA1922DFA9A8"): "micro:bit IO Pin Service",
        UUID("E95DD91D-251D-470A-A062-FA1922DFA9A8"): "micro:bit LED Service",
        UUID("E95D93AF-251D-470A-A062-FA1922DFA9A8"): "micro:bit Event Service",
        UUID("E95D93B0-251D-470A-A062-FA1922DFA9A8"): "micro:bit DFU Control Service",
        UUID("E95D6100-251D-470A-A062-FA1922DFA9A8"): "micro:bit Temperature Service",
        UUID("EF680100-9B35-4933-9B10-52FFA9740042"): "Thingy Configuration Service",
        UUID("EF680200-9B35-4933-9B10-52FFA9740042"): "Thingy Weather Station Service",
        UUID("EF680300-9B35-4933-9B10-52FFA9740042"): "Thingy UI Service",
        UUID("EF680400-9B35-4933-9B10-52FFA9740042"): "Thingy Motion Service",
        UUID("EF680500-9B35-4933-9B10-52FFA9740042"): "Thingy Sound Service",
        UUID("00001523-1212-EFDE-1523-785FEABCD123"): "Nordic LED and Button Service",
        UUID("6E400001-B5A3-F393-E0A9-E50E24DCCA9E"): "Nordic UART Service",
        UUID("57A70000-9350-11ED-A1EB-0242AC120002"): "Nordic Status Message Service",
        UUID("A3C87500-8ED3-4BDF-8A39-A01BEBEDE295"): "Eddystone Configuration Service",
        UUID("00001530-1212-EFDE-1523-785FEABCD123"): "Legacy DFU Service",
        UUID(
            "8E400001-F315-4F60-9FB8-838830DAEA50",
        ): "Experimental Buttonless DFU Service",
        UUID(
            "E2A00001-EC31-4EC3-A97A-1C34D87E9878",
        ): "Edge Impulse Remote Management Service",
        UUID("8D53DC1D-1DB7-4CD3-868B-8A527460AA84"): "SMP Service",
        UUID(
            "00001623-1212-EFDE-1623-785FEABCD123",
        ): "LEGO® Wireless Protocol v3 Hub Service",
        UUID(
            "00001625-1212-EFDE-1623-785FEABCD123",
        ): "LEGO® Wireless Protocol v3 Bootloader Service",
        UUID("ADAF0100-C332-42A8-93BD-25E905756CB8"): "Adafruit Temperature Service",
        UUID("ADAF0200-C332-42A8-93BD-25E905756CB8"): "Adafruit Accelerometer Service",
        UUID("ADAF0300-C332-42A8-93BD-25E905756CB8"): "Adafruit Light Service",
        UUID("ADAF0400-C332-42A8-93BD-25E905756CB8"): "Adafruit Gyroscope Service",
        UUID("ADAF0500-C332-42A8-93BD-25E905756CB8"): "Adafruit Magnetometer Service",
        UUID("ADAF0600-C332-42A8-93BD-25E905756CB8"): "Adafruit Button Service",
        UUID("ADAF0700-C332-42A8-93BD-25E905756CB8"): "Adafruit Humidity Service",
        UUID("ADAF0800-C332-42A8-93BD-25E905756CB8"): "Adafruit Barometric Service",
        UUID("ADAF0900-C332-42A8-93BD-25E905756CB8"): "Adafruit Addressable Service",
        UUID("ADAF0A00-C332-42A8-93BD-25E905756CB8"): "Adafruit Color Service",
        UUID("ADAF0B00-C332-42A8-93BD-25E905756CB8"): "Adafruit Sound Service",
        UUID("ADAF0C00-C332-42A8-93BD-25E905756CB8"): "Adafruit Tone Service",
        UUID("ADAF0D00-C332-42A8-93BD-25E905756CB8"): "Adafruit Quaternion Service",
        UUID("ADAF0E00-C332-42A8-93BD-25E905756CB8"): "Adafruit Proximity Service",
        UUID(
            "F000FFC0-0451-4000-B000-000000000000",
        ): "Texas Instruments Over-the-Air Download (OAD) Service",
        UUID("0FDA92B2-44A2-4AF2-84F5-FA682BAA2B8D"): "Helium Hotspot Custom Service",
        UUID("54220000-F6A5-4007-A371-722F4EBD8436"): "Memfault Diagnostic Service",
    },
)
